/***********************************************************
 * $Id$
 *
 * FancySAX
 *
 * Copyright (C) 2009-2011 ev-i GmbH & IBCL e.U.
 * Copyright (C) 2011-2013 ITEG IT-Engineers GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ************************************************************/

#ifndef FANCYSAXSIMPLECONTENTHANDLER_H_
#define FANCYSAXSIMPLECONTENTHANDLER_H_

#include <fancysaxcontenthandler.h>

namespace Fancy {

class List;

namespace SAX {

class TagHandler;

class FANCYSAX_API SimpleContentHandler: public virtual Fancy::SAX::ContentHandler {

    Fancy::ObjPtr<Fancy::List> handlers;
    Fancy::ObjPtr<TagHandler> rootHandler;

public:
    typedef Fancy::ObjPtr<SimpleContentHandler> ptr_t;

    /**
     * Instantiate a new simple content handler with a given handler for
     * the document element.
     *
     * @return A new simple content handler instance.
     */
    static ptr_t newInstance(const Fancy::ObjPtr<TagHandler> &rootHandler);

    /**
     * @overload
     */
    virtual void startElementNs (const char * localname,
                                 const char * prefix,
                                 const char * URI,
                                 int nb_namespaces,
                                 const char ** namespaces,
                                 int nb_attributes,
                                 int nb_defaulted,
                                 const Attribute* attributes);

    /**
     * @overload
     */
    virtual void endElementNs (const char * localname,
                               const char * prefix,
                               const char * URI);

    /**
     * @overload
     */
    virtual void characters (const char *ch,
                             int len);

    /**
     * @overload
     */
    virtual void startDocument ();

    /**
     * @overload
     */
    virtual void endDocument ();

protected:
    SimpleContentHandler(const Fancy::ObjPtr<TagHandler> &rootHandler);
    virtual ~SimpleContentHandler();
};

}

}

#endif /* FANCYSAXSIMPLECONTENTHANDLER_H_ */
